# Changelog

## [0.2.0](https://github.com/open-feature/python-sdk-contrib/compare/openfeature-hooks-opentelemetry/v0.1.3...openfeature-hooks-opentelemetry/v0.2.0) (2025-02-21)


### ⚠ BREAKING CHANGES

* drop Python 3.8 support ([#187](https://github.com/open-feature/python-sdk-contrib/issues/187))

### 🐛 Bug Fixes

* fix types for hints in OTel TracingHook ([#73](https://github.com/open-feature/python-sdk-contrib/issues/73)) ([24260fb](https://github.com/open-feature/python-sdk-contrib/commit/24260fb519d18590d82e9aae1cf824b9e6ca7f17))
* remove modifications to license files ([#81](https://github.com/open-feature/python-sdk-contrib/issues/81)) ([a23f61e](https://github.com/open-feature/python-sdk-contrib/commit/a23f61e1c14c70e45a4bce4a014d5599813f1d28))


### 🧹 Chore

* drop Python 3.8 support ([#187](https://github.com/open-feature/python-sdk-contrib/issues/187)) ([b55cc1e](https://github.com/open-feature/python-sdk-contrib/commit/b55cc1e0f823d05a330c12af6861dbd3bec69c3a))
* update ruff ([#70](https://github.com/open-feature/python-sdk-contrib/issues/70)) ([9411d0f](https://github.com/open-feature/python-sdk-contrib/commit/9411d0f578238037b3c508faf8f23fe35a374b6c))
* update test config ([c16883e](https://github.com/open-feature/python-sdk-contrib/commit/c16883eb06b870b3a8fa4821492f48291208336b))


### 🔄 Refactoring

* add mypy and fix typing issues ([#72](https://github.com/open-feature/python-sdk-contrib/issues/72)) ([b405925](https://github.com/open-feature/python-sdk-contrib/commit/b4059255045cdb7054a35bc338207e23c42ce068))

## [0.1.3](https://github.com/open-feature/python-sdk-contrib/compare/openfeature-hooks-opentelemetry/v0.1.2...openfeature-hooks-opentelemetry/v0.1.3) (2024-03-17)


### 📚 Documentation

* fix add_hooks call in otel hooks README ([#68](https://github.com/open-feature/python-sdk-contrib/issues/68)) ([8f26275](https://github.com/open-feature/python-sdk-contrib/commit/8f26275a1504086effeb1ca92817671bf9ac27ff))

## [0.1.2](https://github.com/open-feature/python-sdk-contrib/compare/openfeature-hooks-opentelemetry/v0.1.1...openfeature-hooks-opentelemetry/v0.1.2) (2024-03-13)


### 📚 Documentation

* update OTel hook readme with correct import paths ([#65](https://github.com/open-feature/python-sdk-contrib/issues/65)) ([689662b](https://github.com/open-feature/python-sdk-contrib/commit/689662b59ac6117314d707322f26ab4f7b216cc0))

## [0.1.1](https://github.com/open-feature/python-sdk-contrib/compare/openfeature-hooks-opentelemetry-v0.1.0...openfeature-hooks-opentelemetry/v0.1.1) (2024-03-11)


### 📚 Documentation

* update OpenTelemetry hook README ([#49](https://github.com/open-feature/python-sdk-contrib/issues/49)) ([02157f4](https://github.com/open-feature/python-sdk-contrib/commit/02157f447ac7b4dfd7ceced3c6808cf512c680f0))


### 🔄 Refactoring

* move OTel hooks to openfeature.contrib.hook ([#64](https://github.com/open-feature/python-sdk-contrib/issues/64)) ([7075656](https://github.com/open-feature/python-sdk-contrib/commit/707565669cfaf134fe445d54c26e0643756f7f8c))
